import { JsonRpcProvider } from './JsonRpcProvider.js';
export class Eip1193Provider extends JsonRpcProvider {
    constructor(externalProvider, options) {
        super(options);
        this._externalProvider = externalProvider;
        this._dotNetReference = null;
        this._accountChangedHandler = this.accountChanged.bind(this);
        this._chainChangedHandler = this.chainChanged.bind(this);
    }
    isAvailable() {
        return true;
    }
    requestImp(request) {
        return this._externalProvider.request(request);
    }
    configureEvents(dotNetReference) {
        this._dotNetReference = dotNetReference;
        this._externalProvider.on("accountsChanged", this._accountChangedHandler);
        this._externalProvider.on("chainChanged", this._chainChangedHandler);
    }
    //--
    accountChanged(accounts) {
        this._dotNetReference.invokeMethodAsync('AccountChanged', accounts[0]);
    }
    chainChanged(chainId) {
        this._dotNetReference.invokeMethodAsync('ChainChanged', chainId.toString());
    }
    removeEvents() {
        this._externalProvider.removeListener("accountsChanged", this._accountChangedHandler);
        this._externalProvider.removeListener("chainChanged", this._chainChangedHandler);
    }
}
//# sourceMappingURL=Eip1193Provider.js.map