var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { JsonRpcProviderRcpErrorException } from './JsonRpcProvider.js';
export class JsonRpcProviderInterop {
    constructor(provider) {
        this._provider = provider;
    }
    isAvailable() {
        return this._provider.isAvailable();
    }
    request(requestJson, timeoutInMs) {
        return __awaiter(this, void 0, void 0, function* () {
            const request = JSON.parse(requestJson);
            const response = yield this.requestWithResponse(request, timeoutInMs);
            return JSON.stringify(response);
        });
    }
    configureEvents(dotNetReference) {
        this._provider.configureEvents(dotNetReference);
    }
    //--
    requestWithResponse(request, timeoutInMs) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this._provider.request(request, timeoutInMs);
                const rpcResponse = {
                    jsonrpc: "2.0",
                    result: response,
                    id: request.id,
                    error: null
                };
                return rpcResponse;
            }
            catch (e) {
                // rpc errors are throw so we catch all errors
                if (e instanceof JsonRpcProviderRcpErrorException) {
                    // if our provider implementation throw an rpc error - handle it
                    const rpcResponseError = {
                        jsonrpc: "2.0",
                        id: request.id,
                        result: null,
                        error: e.rpcError
                    };
                    return rpcResponseError;
                }
                else if ('code' in e) {
                    // other external errors could be rpc errors - so if the error has a "code" property then assume its an rpc error
                    const rpcResponseError = {
                        jsonrpc: "2.0",
                        id: request.id,
                        result: null,
                        error: e
                    };
                    return rpcResponseError;
                }
                // this is probably some unknown error
                throw e;
            }
        });
    }
}
//# sourceMappingURL=JsonRpcProviderInterop.js.map