import { JsonRpcProvider, JsonRpcProviderRcpErrorException } from './JsonRpcProvider.js';
export class LegacyProvider extends JsonRpcProvider {
    constructor(externalProvider, options) {
        super(options);
        this._fetchFunc = this.buildFetchFunc(externalProvider);
        this._externalProvider = externalProvider;
    }
    isAvailable() {
        return true;
    }
    requestImp(request) {
        return this._fetchFunc(request);
    }
    configureEvents(dotNetReference) {
        // do nothing - legacy providers do not support a standard event interface
    }
    //--
    buildFetchFunc(externalProvider) {
        if (externalProvider.sendAsync) {
            return this.buildLegacyFetchFunc(externalProvider.sendAsync);
        }
        else if (externalProvider.send) {
            return this.buildLegacyFetchFunc(externalProvider.send);
        }
        else {
            throw "Unsupported legacy externalProvider";
        }
    }
    buildLegacyFetchFunc(sendFunc) {
        return function (request) {
            return new Promise((resolve, reject) => {
                sendFunc(request, (error, response) => {
                    // a non rpc error
                    if (error) {
                        return reject(error);
                    }
                    // a rpc error = build an rpc error object reject (throw) that object
                    if (response.error) {
                        const e = new JsonRpcProviderRcpErrorException(response.error);
                        return reject(e);
                    }
                    resolve(response.result);
                });
            });
        };
    }
}
//# sourceMappingURL=LegacyProvider.js.map